non_little_cpus

Function non_little_cpus 

fn non_little_cpus() -> Result<Option<Vec<u16>>, String>
Determine the CPU ids of cores not in the little class.

Returns Err on internal / parsing errors. Returns Ok(None) if the cpu is not heterogeneous, or if there would only be a single cpu in the non-little group.