pin_thread_to_medium_or_large_cpus

Function pin_thread_to_medium_or_large_cpus 

pub(super) fn pin_thread_to_medium_or_large_cpus() -> Result<(), String>
Try and pin this thread to cpu cores above the smallest capacity class.

If the cpu only has one kind of core, or only one core above the smallest capacity class this is a no-op.